==> haskell-tasty-hedgehog-0.2.0.0-53-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-hedgehog
version: 0.2.0.0
id: tasty-hedgehog-0.2.0.0-91mOOGObXlRDfVAcu941eP
key: tasty-hedgehog-0.2.0.0-91mOOGObXlRDfVAcu941eP
license: BSD-3-Clause
copyright: Copyright (c) 2017, Commonwealth Scientific and Industrial Research Organisation (CSIRO) ABN 41 687 119 230.
maintainer: dave.laing.80@gmail.com
author: Dave Laing
homepage: https://github.com/qfpl/tasty-hedghog
synopsis: Integration for tasty and hedgehog.
description:
    Integrates the hedgehog testing library with the tasty testing framework.
category: Testing
abi: fd96811eb05a4912eface1b8bf55e197
exposed: True
exposed-modules:
    Test.Tasty.Hedgehog
import-dirs: /usr/lib/ghc-8.4.3/site-local/tasty-hedgehog-0.2.0.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/tasty-hedgehog-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/tasty-hedgehog-0.2.0.0
hs-libraries: HStasty-hedgehog-0.2.0.0-91mOOGObXlRDfVAcu941eP
depends:
    base-4.11.1.0 tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO
    tasty-1.1.0.4-JVxQGtLb8FS2ZJgzdlYC9o
    hedgehog-0.6.1-1iFIuNB8aWk3OZHrIxOLE3
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=4bf567357cce5e796341c1faefad6985
             tasty-1.1.0.4-JVxQGtLb8FS2ZJgzdlYC9o=45655e1f87d1aadd2caf3019f95a0f8e
             hedgehog-0.6.1-1iFIuNB8aWk3OZHrIxOLE3=bd5382508a30bfaf2c27001969b158b3
haddock-interfaces: /usr/share/doc/haskell-tasty-hedgehog/html/tasty-hedgehog.haddock
haddock-html: /usr/share/doc/haskell-tasty-hedgehog/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-hedgehog-0.2.0.0-56-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-hedgehog
version: 0.2.0.0
id: tasty-hedgehog-0.2.0.0-985Dpw9FMFl8tr5ROuvNMB
key: tasty-hedgehog-0.2.0.0-985Dpw9FMFl8tr5ROuvNMB
license: BSD-3-Clause
copyright: Copyright (c) 2017, Commonwealth Scientific and Industrial Research Organisation (CSIRO) ABN 41 687 119 230.
maintainer: dave.laing.80@gmail.com
author: Dave Laing
homepage: https://github.com/qfpl/tasty-hedghog
synopsis: Integration for tasty and hedgehog.
description:
    Integrates the hedgehog testing library with the tasty testing framework.
category: Testing
abi: c5d5dbecbf47b040b8deb22f05d451df
exposed: True
exposed-modules:
    Test.Tasty.Hedgehog
import-dirs: /usr/lib/ghc-8.6.1/site-local/tasty-hedgehog-0.2.0.0
library-dirs: /usr/lib/ghc-8.6.1/site-local/tasty-hedgehog-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/tasty-hedgehog-0.2.0.0
hs-libraries: HStasty-hedgehog-0.2.0.0-985Dpw9FMFl8tr5ROuvNMB
depends:
    base-4.12.0.0 hedgehog-0.6.1-C67Lo8M6xC5BiX1ulU0z7t
    tagged-0.8.6-FABECvKnqYbBCttH1EeJvB
    tasty-1.1.0.4-KA2OQv2hxns8llKnTblJO9
haddock-interfaces: /usr/share/doc/haskell-tasty-hedgehog/html/tasty-hedgehog.haddock
haddock-html: /usr/share/doc/haskell-tasty-hedgehog/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
